"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ArchiveReply(google.protobuf.message.Message):
    """-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ITEM_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    EPISODIC_BUTTON_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    @property
    def item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BiliSpaceVideo]:
        """"""
        pass
    count: builtins.int
    """"""

    @property
    def episodic_button(self) -> global___EpisodicButton:
        """"""
        pass
    @property
    def order(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OrderConfig]:
        """"""
        pass
    def __init__(self,
        *,
        item: typing.Optional[typing.Iterable[global___BiliSpaceVideo]] = ...,
        count: builtins.int = ...,
        episodic_button: typing.Optional[global___EpisodicButton] = ...,
        order: typing.Optional[typing.Iterable[global___OrderConfig]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["episodic_button",b"episodic_button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["count",b"count","episodic_button",b"episodic_button","item",b"item","order",b"order"]) -> None: ...
global___ArchiveReply = ArchiveReply

class ArchiveReq(google.protobuf.message.Message):
    """-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VMID_FIELD_NUMBER: builtins.int
    PN_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    vmid: builtins.int
    """"""

    pn: builtins.int
    """"""

    ps: builtins.int
    """"""

    order: typing.Text
    """"""

    def __init__(self,
        *,
        vmid: builtins.int = ...,
        pn: builtins.int = ...,
        ps: builtins.int = ...,
        order: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["order",b"order","pn",b"pn","ps",b"ps","vmid",b"vmid"]) -> None: ...
global___ArchiveReq = ArchiveReq

class Badge(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BORDER_COLOR_FIELD_NUMBER: builtins.int
    BORDER_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_STYLE_FIELD_NUMBER: builtins.int
    text: typing.Text
    """"""

    text_color: typing.Text
    """"""

    text_color_night: typing.Text
    """"""

    bg_color: typing.Text
    """"""

    bg_color_night: typing.Text
    """"""

    border_color: typing.Text
    """"""

    border_color_night: typing.Text
    """"""

    bg_style: builtins.int
    """"""

    def __init__(self,
        *,
        text: typing.Text = ...,
        text_color: typing.Text = ...,
        text_color_night: typing.Text = ...,
        bg_color: typing.Text = ...,
        bg_color_night: typing.Text = ...,
        border_color: typing.Text = ...,
        border_color_night: typing.Text = ...,
        bg_style: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color",b"bg_color","bg_color_night",b"bg_color_night","bg_style",b"bg_style","border_color",b"border_color","border_color_night",b"border_color_night","text",b"text","text_color",b"text_color","text_color_night",b"text_color_night"]) -> None: ...
global___Badge = Badge

class BiliSpaceVideo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    TNAME_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    PARAM_FIELD_NUMBER: builtins.int
    DANMAKU_FIELD_NUMBER: builtins.int
    PLAY_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    IS_POPULAR_FIELD_NUMBER: builtins.int
    BADGES_FIELD_NUMBER: builtins.int
    COVER_RIGHT_FIELD_NUMBER: builtins.int
    BVID_FIELD_NUMBER: builtins.int
    IS_STEINS_FIELD_NUMBER: builtins.int
    IS_UGCPAY_FIELD_NUMBER: builtins.int
    IS_COOPERATION_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    tname: typing.Text
    """"""

    duration: builtins.int
    """"""

    cover: typing.Text
    """"""

    uri: typing.Text
    """"""

    param: typing.Text
    """"""

    danmaku: typing.Text
    """"""

    play: builtins.int
    """"""

    ctime: builtins.int
    """"""

    state: builtins.bool
    """"""

    is_popular: builtins.bool
    """"""

    @property
    def badges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Badge]:
        """"""
        pass
    cover_right: typing.Text
    """"""

    bvid: typing.Text
    """"""

    is_steins: builtins.bool
    """"""

    is_ugcpay: builtins.bool
    """"""

    is_cooperation: builtins.bool
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        tname: typing.Text = ...,
        duration: builtins.int = ...,
        cover: typing.Text = ...,
        uri: typing.Text = ...,
        param: typing.Text = ...,
        danmaku: typing.Text = ...,
        play: builtins.int = ...,
        ctime: builtins.int = ...,
        state: builtins.bool = ...,
        is_popular: builtins.bool = ...,
        badges: typing.Optional[typing.Iterable[global___Badge]] = ...,
        cover_right: typing.Text = ...,
        bvid: typing.Text = ...,
        is_steins: builtins.bool = ...,
        is_ugcpay: builtins.bool = ...,
        is_cooperation: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["badges",b"badges","bvid",b"bvid","cover",b"cover","cover_right",b"cover_right","ctime",b"ctime","danmaku",b"danmaku","duration",b"duration","is_cooperation",b"is_cooperation","is_popular",b"is_popular","is_steins",b"is_steins","is_ugcpay",b"is_ugcpay","param",b"param","play",b"play","state",b"state","title",b"title","tname",b"tname","uri",b"uri"]) -> None: ...
global___BiliSpaceVideo = BiliSpaceVideo

class EpisodicButton(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    text: typing.Text
    """"""

    uri: typing.Text
    """"""

    def __init__(self,
        *,
        text: typing.Text = ...,
        uri: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text",b"text","uri",b"uri"]) -> None: ...
global___EpisodicButton = EpisodicButton

class OrderConfig(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    value: typing.Text
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        value: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["title",b"title","value",b"value"]) -> None: ...
global___OrderConfig = OrderConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/dynamic/interfaces/feed/v1/api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.dynamic.common import dynamic_pb2 as bilibili_dot_dynamic_dot_common_dot_dynamic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-bilibili/dynamic/interfaces/feed/v1/api.proto\x12\x1d\x62ilibili.main.dynamic.feed.v1\x1a%bilibili/dynamic/common/dynamic.proto\"\xf0\x04\n\x0c\x43reateDynReq\x12.\n\x04meta\x18\x01 \x01(\x0b\x32 .bilibili.dynamic.UserCreateMeta\x12\x30\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x1f.bilibili.dynamic.CreateContent\x12,\n\x05scene\x18\x03 \x01(\x0e\x32\x1d.bilibili.dynamic.CreateScene\x12)\n\x04pics\x18\x04 \x03(\x0b\x32\x1b.bilibili.dynamic.CreatePic\x12\x31\n\nrepost_src\x18\x05 \x01(\x0b\x32\x1d.bilibili.dynamic.DynIdentity\x12/\n\x05video\x18\x06 \x01(\x0b\x32 .bilibili.dynamic.CreateDynVideo\x12\x13\n\x0bsketch_type\x18\x07 \x01(\x03\x12(\n\x06sketch\x18\x08 \x01(\x0b\x32\x18.bilibili.dynamic.Sketch\x12*\n\x07program\x18\t \x01(\x0b\x32\x19.bilibili.dynamic.Program\x12,\n\x07\x64yn_tag\x18\n \x01(\x0b\x32\x1b.bilibili.dynamic.CreateTag\x12\x37\n\x0b\x61ttach_card\x18\x0b \x01(\x0b\x32\".bilibili.dynamic.CreateAttachCard\x12.\n\x06option\x18\x0c \x01(\x0b\x32\x1e.bilibili.dynamic.CreateOption\x12,\n\x05topic\x18\r \x01(\x0b\x32\x1d.bilibili.dynamic.CreateTopic\x12\x11\n\tupload_id\x18\x0e \x01(\t\"\x84\x01\n\x12\x43reateInitCheckReq\x12\r\n\x05scene\x18\x01 \x01(\x05\x12,\n\x04meta\x18\x02 \x01(\x0b\x32\x1e.bilibili.dynamic.MetaDataCtrl\x12\x31\n\x06repost\x18\x03 \x01(\x0b\x32!.bilibili.dynamic.RepostInitCheck\"&\n\x12\x43reatePageInfosReq\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\"W\n\x12\x43reatePageInfosRsp\x12\x41\n\x05topic\x18\x01 \x01(\x0b\x32\x32.bilibili.main.dynamic.feed.v1.CreatePageTopicInfo\";\n\x13\x43reatePageTopicInfo\x12\x10\n\x08topic_id\x18\x01 \x01(\x03\x12\x12\n\ntopic_name\x18\x02 \x01(\t\"h\n\x1e\x43reatePermissionButtonClickReq\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x38.bilibili.main.dynamic.feed.v1.DynamicButtonClickBizType\" \n\x1e\x43reatePermissionButtonClickRsp\"\x1a\n\x18\x43reatePlusButtonClickReq\"\x1a\n\x18\x43reatePlusButtonClickRsp\"\x17\n\x15\x44ynamicButtonClickReq\"\x17\n\x15\x44ynamicButtonClickRsp\"\x0e\n\x0cHotSearchReq\"w\n\x0cHotSearchRsp\x12?\n\x05items\x18\x01 \x03(\x0b\x32\x30.bilibili.main.dynamic.feed.v1.HotSearchRsp.Item\x12\x0f\n\x07version\x18\x02 \x01(\t\x1a\x15\n\x04Item\x12\r\n\x05words\x18\x01 \x01(\t\"\x98\x01\n\x15ReserveButtonClickReq\x12\x0b\n\x03uid\x18\x01 \x01(\x03\x12\x12\n\nreserve_id\x18\x02 \x01(\x03\x12\x15\n\rreserve_total\x18\x03 \x01(\x03\x12\x16\n\x0e\x63ur_btn_status\x18\x04 \x01(\x05\x12\r\n\x05spmid\x18\x05 \x01(\t\x12\x0e\n\x06\x64yn_id\x18\x06 \x01(\x03\x12\x10\n\x08\x64yn_type\x18\x07 \x01(\x03\"\x92\x02\n\x16ReserveButtonClickResp\x12L\n\x10\x66inal_btn_status\x18\x01 \x01(\x0e\x32\x32.bilibili.main.dynamic.feed.v1.ReserveButtonStatus\x12\x42\n\x08\x62tn_mode\x18\x02 \x01(\x0e\x32\x30.bilibili.main.dynamic.feed.v1.ReserveButtonMode\x12\x16\n\x0ereserve_update\x18\x03 \x01(\x03\x12\x13\n\x0b\x64\x65sc_update\x18\x04 \x01(\t\x12\x14\n\x0chas_activity\x18\x05 \x01(\x08\x12\x14\n\x0c\x61\x63tivity_url\x18\x06 \x01(\t\x12\r\n\x05toast\x18\x07 \x01(\t\"m\n\x0eSubmitCheckReq\x12\x30\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x1f.bilibili.dynamic.CreateContent\x12)\n\x04pics\x18\x02 \x03(\x0b\x32\x1b.bilibili.dynamic.CreatePic\"\x10\n\x0eSubmitCheckRsp\"%\n\nSuggestReq\x12\t\n\x01s\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\x05\"=\n\nSuggestRsp\x12\x0c\n\x04list\x18\x01 \x03(\t\x12\x10\n\x08track_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t*\x95\x01\n\x19\x44ynamicButtonClickBizType\x12&\n\"DYNAMIC_BUTTON_CLICK_BIZ_TYPE_NONE\x10\x00\x12&\n\"DYNAMIC_BUTTON_CLICK_BIZ_TYPE_LIVE\x10\x01\x12(\n$DYNAMIC_BUTTON_CLICK_BIZ_TYPE_DYN_UP\x10\x02*u\n\x11ReserveButtonMode\x12\x1c\n\x18RESERVE_BUTTON_MODE_NONE\x10\x00\x12\x1f\n\x1bRESERVE_BUTTON_MODE_RESERVE\x10\x01\x12!\n\x1dRESERVE_BUTTON_MODE_UP_CANCEL\x10\x02*y\n\x13ReserveButtonStatus\x12\x1e\n\x1aRESERVE_BUTTON_STATUS_NONE\x10\x00\x12!\n\x1dRESERVE_BUTTON_STATUS_UNCHECK\x10\x01\x12\x1f\n\x1bRESERVE_BUTTON_STATUS_CHECK\x10\x02\x32\x88\x0b\n\x04\x46\x65\x65\x64\x12g\n\x0f\x43reateInitCheck\x12\x31.bilibili.main.dynamic.feed.v1.CreateInitCheckReq\x1a!.bilibili.dynamic.CreateCheckResp\x12k\n\x0bSubmitCheck\x12-.bilibili.main.dynamic.feed.v1.SubmitCheckReq\x1a-.bilibili.main.dynamic.feed.v1.SubmitCheckRsp\x12V\n\tCreateDyn\x12+.bilibili.main.dynamic.feed.v1.CreateDynReq\x1a\x1c.bilibili.dynamic.CreateResp\x12T\n\x0cGetUidByName\x12!.bilibili.dynamic.GetUidByNameReq\x1a!.bilibili.dynamic.GetUidByNameRsp\x12\x42\n\x06\x41tList\x12\x1b.bilibili.dynamic.AtListReq\x1a\x1b.bilibili.dynamic.AtListRsp\x12\x46\n\x08\x41tSearch\x12\x1d.bilibili.dynamic.AtSearchReq\x1a\x1b.bilibili.dynamic.AtListRsp\x12\x81\x01\n\x12ReserveButtonClick\x12\x34.bilibili.main.dynamic.feed.v1.ReserveButtonClickReq\x1a\x35.bilibili.main.dynamic.feed.v1.ReserveButtonClickResp\x12\x89\x01\n\x15\x43reatePlusButtonClick\x12\x37.bilibili.main.dynamic.feed.v1.CreatePlusButtonClickReq\x1a\x37.bilibili.main.dynamic.feed.v1.CreatePlusButtonClickRsp\x12\x65\n\tHotSearch\x12+.bilibili.main.dynamic.feed.v1.HotSearchReq\x1a+.bilibili.main.dynamic.feed.v1.HotSearchRsp\x12_\n\x07Suggest\x12).bilibili.main.dynamic.feed.v1.SuggestReq\x1a).bilibili.main.dynamic.feed.v1.SuggestRsp\x12\x80\x01\n\x12\x44ynamicButtonClick\x12\x34.bilibili.main.dynamic.feed.v1.DynamicButtonClickReq\x1a\x34.bilibili.main.dynamic.feed.v1.DynamicButtonClickRsp\x12\x9b\x01\n\x1b\x43reatePermissionButtonClick\x12=.bilibili.main.dynamic.feed.v1.CreatePermissionButtonClickReq\x1a=.bilibili.main.dynamic.feed.v1.CreatePermissionButtonClickRsp\x12w\n\x0f\x43reatePageInfos\x12\x31.bilibili.main.dynamic.feed.v1.CreatePageInfosReq\x1a\x31.bilibili.main.dynamic.feed.v1.CreatePageInfosRspb\x06proto3')

_DYNAMICBUTTONCLICKBIZTYPE = DESCRIPTOR.enum_types_by_name['DynamicButtonClickBizType']
DynamicButtonClickBizType = enum_type_wrapper.EnumTypeWrapper(_DYNAMICBUTTONCLICKBIZTYPE)
_RESERVEBUTTONMODE = DESCRIPTOR.enum_types_by_name['ReserveButtonMode']
ReserveButtonMode = enum_type_wrapper.EnumTypeWrapper(_RESERVEBUTTONMODE)
_RESERVEBUTTONSTATUS = DESCRIPTOR.enum_types_by_name['ReserveButtonStatus']
ReserveButtonStatus = enum_type_wrapper.EnumTypeWrapper(_RESERVEBUTTONSTATUS)
DYNAMIC_BUTTON_CLICK_BIZ_TYPE_NONE = 0
DYNAMIC_BUTTON_CLICK_BIZ_TYPE_LIVE = 1
DYNAMIC_BUTTON_CLICK_BIZ_TYPE_DYN_UP = 2
RESERVE_BUTTON_MODE_NONE = 0
RESERVE_BUTTON_MODE_RESERVE = 1
RESERVE_BUTTON_MODE_UP_CANCEL = 2
RESERVE_BUTTON_STATUS_NONE = 0
RESERVE_BUTTON_STATUS_UNCHECK = 1
RESERVE_BUTTON_STATUS_CHECK = 2


_CREATEDYNREQ = DESCRIPTOR.message_types_by_name['CreateDynReq']
_CREATEINITCHECKREQ = DESCRIPTOR.message_types_by_name['CreateInitCheckReq']
_CREATEPAGEINFOSREQ = DESCRIPTOR.message_types_by_name['CreatePageInfosReq']
_CREATEPAGEINFOSRSP = DESCRIPTOR.message_types_by_name['CreatePageInfosRsp']
_CREATEPAGETOPICINFO = DESCRIPTOR.message_types_by_name['CreatePageTopicInfo']
_CREATEPERMISSIONBUTTONCLICKREQ = DESCRIPTOR.message_types_by_name['CreatePermissionButtonClickReq']
_CREATEPERMISSIONBUTTONCLICKRSP = DESCRIPTOR.message_types_by_name['CreatePermissionButtonClickRsp']
_CREATEPLUSBUTTONCLICKREQ = DESCRIPTOR.message_types_by_name['CreatePlusButtonClickReq']
_CREATEPLUSBUTTONCLICKRSP = DESCRIPTOR.message_types_by_name['CreatePlusButtonClickRsp']
_DYNAMICBUTTONCLICKREQ = DESCRIPTOR.message_types_by_name['DynamicButtonClickReq']
_DYNAMICBUTTONCLICKRSP = DESCRIPTOR.message_types_by_name['DynamicButtonClickRsp']
_HOTSEARCHREQ = DESCRIPTOR.message_types_by_name['HotSearchReq']
_HOTSEARCHRSP = DESCRIPTOR.message_types_by_name['HotSearchRsp']
_HOTSEARCHRSP_ITEM = _HOTSEARCHRSP.nested_types_by_name['Item']
_RESERVEBUTTONCLICKREQ = DESCRIPTOR.message_types_by_name['ReserveButtonClickReq']
_RESERVEBUTTONCLICKRESP = DESCRIPTOR.message_types_by_name['ReserveButtonClickResp']
_SUBMITCHECKREQ = DESCRIPTOR.message_types_by_name['SubmitCheckReq']
_SUBMITCHECKRSP = DESCRIPTOR.message_types_by_name['SubmitCheckRsp']
_SUGGESTREQ = DESCRIPTOR.message_types_by_name['SuggestReq']
_SUGGESTRSP = DESCRIPTOR.message_types_by_name['SuggestRsp']
CreateDynReq = _reflection.GeneratedProtocolMessageType('CreateDynReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDYNREQ,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.CreateDynReq)
  })
_sym_db.RegisterMessage(CreateDynReq)

CreateInitCheckReq = _reflection.GeneratedProtocolMessageType('CreateInitCheckReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEINITCHECKREQ,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.CreateInitCheckReq)
  })
_sym_db.RegisterMessage(CreateInitCheckReq)

CreatePageInfosReq = _reflection.GeneratedProtocolMessageType('CreatePageInfosReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPAGEINFOSREQ,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.CreatePageInfosReq)
  })
_sym_db.RegisterMessage(CreatePageInfosReq)

CreatePageInfosRsp = _reflection.GeneratedProtocolMessageType('CreatePageInfosRsp', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPAGEINFOSRSP,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.CreatePageInfosRsp)
  })
_sym_db.RegisterMessage(CreatePageInfosRsp)

CreatePageTopicInfo = _reflection.GeneratedProtocolMessageType('CreatePageTopicInfo', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPAGETOPICINFO,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.CreatePageTopicInfo)
  })
_sym_db.RegisterMessage(CreatePageTopicInfo)

CreatePermissionButtonClickReq = _reflection.GeneratedProtocolMessageType('CreatePermissionButtonClickReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPERMISSIONBUTTONCLICKREQ,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.CreatePermissionButtonClickReq)
  })
_sym_db.RegisterMessage(CreatePermissionButtonClickReq)

CreatePermissionButtonClickRsp = _reflection.GeneratedProtocolMessageType('CreatePermissionButtonClickRsp', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPERMISSIONBUTTONCLICKRSP,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.CreatePermissionButtonClickRsp)
  })
_sym_db.RegisterMessage(CreatePermissionButtonClickRsp)

CreatePlusButtonClickReq = _reflection.GeneratedProtocolMessageType('CreatePlusButtonClickReq', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPLUSBUTTONCLICKREQ,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.CreatePlusButtonClickReq)
  })
_sym_db.RegisterMessage(CreatePlusButtonClickReq)

CreatePlusButtonClickRsp = _reflection.GeneratedProtocolMessageType('CreatePlusButtonClickRsp', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPLUSBUTTONCLICKRSP,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.CreatePlusButtonClickRsp)
  })
_sym_db.RegisterMessage(CreatePlusButtonClickRsp)

DynamicButtonClickReq = _reflection.GeneratedProtocolMessageType('DynamicButtonClickReq', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICBUTTONCLICKREQ,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.DynamicButtonClickReq)
  })
_sym_db.RegisterMessage(DynamicButtonClickReq)

DynamicButtonClickRsp = _reflection.GeneratedProtocolMessageType('DynamicButtonClickRsp', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICBUTTONCLICKRSP,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.DynamicButtonClickRsp)
  })
_sym_db.RegisterMessage(DynamicButtonClickRsp)

HotSearchReq = _reflection.GeneratedProtocolMessageType('HotSearchReq', (_message.Message,), {
  'DESCRIPTOR' : _HOTSEARCHREQ,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.HotSearchReq)
  })
_sym_db.RegisterMessage(HotSearchReq)

HotSearchRsp = _reflection.GeneratedProtocolMessageType('HotSearchRsp', (_message.Message,), {

  'Item' : _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), {
    'DESCRIPTOR' : _HOTSEARCHRSP_ITEM,
    '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
    # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.HotSearchRsp.Item)
    })
  ,
  'DESCRIPTOR' : _HOTSEARCHRSP,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.HotSearchRsp)
  })
_sym_db.RegisterMessage(HotSearchRsp)
_sym_db.RegisterMessage(HotSearchRsp.Item)

ReserveButtonClickReq = _reflection.GeneratedProtocolMessageType('ReserveButtonClickReq', (_message.Message,), {
  'DESCRIPTOR' : _RESERVEBUTTONCLICKREQ,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.ReserveButtonClickReq)
  })
_sym_db.RegisterMessage(ReserveButtonClickReq)

ReserveButtonClickResp = _reflection.GeneratedProtocolMessageType('ReserveButtonClickResp', (_message.Message,), {
  'DESCRIPTOR' : _RESERVEBUTTONCLICKRESP,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.ReserveButtonClickResp)
  })
_sym_db.RegisterMessage(ReserveButtonClickResp)

SubmitCheckReq = _reflection.GeneratedProtocolMessageType('SubmitCheckReq', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITCHECKREQ,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.SubmitCheckReq)
  })
_sym_db.RegisterMessage(SubmitCheckReq)

SubmitCheckRsp = _reflection.GeneratedProtocolMessageType('SubmitCheckRsp', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITCHECKRSP,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.SubmitCheckRsp)
  })
_sym_db.RegisterMessage(SubmitCheckRsp)

SuggestReq = _reflection.GeneratedProtocolMessageType('SuggestReq', (_message.Message,), {
  'DESCRIPTOR' : _SUGGESTREQ,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.SuggestReq)
  })
_sym_db.RegisterMessage(SuggestReq)

SuggestRsp = _reflection.GeneratedProtocolMessageType('SuggestRsp', (_message.Message,), {
  'DESCRIPTOR' : _SUGGESTRSP,
  '__module__' : 'bilibili.dynamic.interfaces.feed.v1.api_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.main.dynamic.feed.v1.SuggestRsp)
  })
_sym_db.RegisterMessage(SuggestRsp)

_FEED = DESCRIPTOR.services_by_name['Feed']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DYNAMICBUTTONCLICKBIZTYPE._serialized_start=2118
  _DYNAMICBUTTONCLICKBIZTYPE._serialized_end=2267
  _RESERVEBUTTONMODE._serialized_start=2269
  _RESERVEBUTTONMODE._serialized_end=2386
  _RESERVEBUTTONSTATUS._serialized_start=2388
  _RESERVEBUTTONSTATUS._serialized_end=2509
  _CREATEDYNREQ._serialized_start=120
  _CREATEDYNREQ._serialized_end=744
  _CREATEINITCHECKREQ._serialized_start=747
  _CREATEINITCHECKREQ._serialized_end=879
  _CREATEPAGEINFOSREQ._serialized_start=881
  _CREATEPAGEINFOSREQ._serialized_end=919
  _CREATEPAGEINFOSRSP._serialized_start=921
  _CREATEPAGEINFOSRSP._serialized_end=1008
  _CREATEPAGETOPICINFO._serialized_start=1010
  _CREATEPAGETOPICINFO._serialized_end=1069
  _CREATEPERMISSIONBUTTONCLICKREQ._serialized_start=1071
  _CREATEPERMISSIONBUTTONCLICKREQ._serialized_end=1175
  _CREATEPERMISSIONBUTTONCLICKRSP._serialized_start=1177
  _CREATEPERMISSIONBUTTONCLICKRSP._serialized_end=1209
  _CREATEPLUSBUTTONCLICKREQ._serialized_start=1211
  _CREATEPLUSBUTTONCLICKREQ._serialized_end=1237
  _CREATEPLUSBUTTONCLICKRSP._serialized_start=1239
  _CREATEPLUSBUTTONCLICKRSP._serialized_end=1265
  _DYNAMICBUTTONCLICKREQ._serialized_start=1267
  _DYNAMICBUTTONCLICKREQ._serialized_end=1290
  _DYNAMICBUTTONCLICKRSP._serialized_start=1292
  _DYNAMICBUTTONCLICKRSP._serialized_end=1315
  _HOTSEARCHREQ._serialized_start=1317
  _HOTSEARCHREQ._serialized_end=1331
  _HOTSEARCHRSP._serialized_start=1333
  _HOTSEARCHRSP._serialized_end=1452
  _HOTSEARCHRSP_ITEM._serialized_start=1431
  _HOTSEARCHRSP_ITEM._serialized_end=1452
  _RESERVEBUTTONCLICKREQ._serialized_start=1455
  _RESERVEBUTTONCLICKREQ._serialized_end=1607
  _RESERVEBUTTONCLICKRESP._serialized_start=1610
  _RESERVEBUTTONCLICKRESP._serialized_end=1884
  _SUBMITCHECKREQ._serialized_start=1886
  _SUBMITCHECKREQ._serialized_end=1995
  _SUBMITCHECKRSP._serialized_start=1997
  _SUBMITCHECKRSP._serialized_end=2013
  _SUGGESTREQ._serialized_start=2015
  _SUGGESTREQ._serialized_end=2052
  _SUGGESTRSP._serialized_start=2054
  _SUGGESTRSP._serialized_end=2115
  _FEED._serialized_start=2512
  _FEED._serialized_end=3928
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ModeType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ModeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ModeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NORMAL: _ModeType.ValueType  # 0
    """正常模式"""

    TEENAGERS: _ModeType.ValueType  # 1
    """青少年模式"""

    LESSONS: _ModeType.ValueType  # 2
    """课堂模式"""

class ModeType(_ModeType, metaclass=_ModeTypeEnumTypeWrapper):
    """模式类型"""
    pass

NORMAL: ModeType.ValueType  # 0
"""正常模式"""

TEENAGERS: ModeType.ValueType  # 1
"""青少年模式"""

LESSONS: ModeType.ValueType  # 2
"""课堂模式"""

global___ModeType = ModeType


class Restriction(google.protobuf.message.Message):
    """限制条件"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    LESSONS_MODE_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    REVIEW_FIELD_NUMBER: builtins.int
    DISABLE_RCMD_FIELD_NUMBER: builtins.int
    teenagers_mode: builtins.bool
    """青少年模式开关状态"""

    lessons_mode: builtins.bool
    """课堂模式开关状态"""

    mode: global___ModeType.ValueType
    """模式类型(旧版)"""

    review: builtins.bool
    """app 审核review状态"""

    disable_rcmd: builtins.bool
    """"""

    def __init__(self,
        *,
        teenagers_mode: builtins.bool = ...,
        lessons_mode: builtins.bool = ...,
        mode: global___ModeType.ValueType = ...,
        review: builtins.bool = ...,
        disable_rcmd: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_rcmd",b"disable_rcmd","lessons_mode",b"lessons_mode","mode",b"mode","review",b"review","teenagers_mode",b"teenagers_mode"]) -> None: ...
global___Restriction = Restriction



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AdInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CREATIVE_ID_FIELD_NUMBER: builtins.int
    CREATIVE_TYPE_FIELD_NUMBER: builtins.int
    CARD_TYPE_FIELD_NUMBER: builtins.int
    CREATIVE_CONTENT_FIELD_NUMBER: builtins.int
    AD_CB_FIELD_NUMBER: builtins.int
    RESOURCE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    IS_AD_FIELD_NUMBER: builtins.int
    CM_MARK_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    IS_AD_LOC_FIELD_NUMBER: builtins.int
    CARD_INDEX_FIELD_NUMBER: builtins.int
    CLIENT_IP_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    CREATIVE_STYLE_FIELD_NUMBER: builtins.int
    creative_id: builtins.int
    """"""

    creative_type: builtins.int
    """"""

    card_type: builtins.int
    """"""

    @property
    def creative_content(self) -> global___CreativeContent:
        """"""
        pass
    ad_cb: typing.Text
    """"""

    resource: builtins.int
    """"""

    source: builtins.int
    """"""

    request_id: typing.Text
    """"""

    is_ad: builtins.bool
    """"""

    cm_mark: builtins.int
    """"""

    index: builtins.int
    """"""

    is_ad_loc: builtins.bool
    """"""

    card_index: builtins.int
    """"""

    client_ip: typing.Text
    """"""

    extra: builtins.bytes
    """"""

    creative_style: builtins.int
    """"""

    def __init__(self,
        *,
        creative_id: builtins.int = ...,
        creative_type: builtins.int = ...,
        card_type: builtins.int = ...,
        creative_content: typing.Optional[global___CreativeContent] = ...,
        ad_cb: typing.Text = ...,
        resource: builtins.int = ...,
        source: builtins.int = ...,
        request_id: typing.Text = ...,
        is_ad: builtins.bool = ...,
        cm_mark: builtins.int = ...,
        index: builtins.int = ...,
        is_ad_loc: builtins.bool = ...,
        card_index: builtins.int = ...,
        client_ip: typing.Text = ...,
        extra: builtins.bytes = ...,
        creative_style: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creative_content",b"creative_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_cb",b"ad_cb","card_index",b"card_index","card_type",b"card_type","client_ip",b"client_ip","cm_mark",b"cm_mark","creative_content",b"creative_content","creative_id",b"creative_id","creative_style",b"creative_style","creative_type",b"creative_type","extra",b"extra","index",b"index","is_ad",b"is_ad","is_ad_loc",b"is_ad_loc","request_id",b"request_id","resource",b"resource","source",b"source"]) -> None: ...
global___AdInfo = AdInfo

class CreativeContent(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    VIDEO_ID_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    IMAGE_URL_FIELD_NUMBER: builtins.int
    IMAGE_MD5_FIELD_NUMBER: builtins.int
    LOG_URL_FIELD_NUMBER: builtins.int
    LOG_MD5_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    CLICK_URL_FIELD_NUMBER: builtins.int
    SHOW_URL_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    description: typing.Text
    """"""

    video_id: builtins.int
    """"""

    username: typing.Text
    """"""

    image_url: typing.Text
    """"""

    image_md5: typing.Text
    """"""

    log_url: typing.Text
    """"""

    log_md5: typing.Text
    """"""

    url: typing.Text
    """"""

    click_url: typing.Text
    """"""

    show_url: typing.Text
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        description: typing.Text = ...,
        video_id: builtins.int = ...,
        username: typing.Text = ...,
        image_url: typing.Text = ...,
        image_md5: typing.Text = ...,
        log_url: typing.Text = ...,
        log_md5: typing.Text = ...,
        url: typing.Text = ...,
        click_url: typing.Text = ...,
        show_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["click_url",b"click_url","description",b"description","image_md5",b"image_md5","image_url",b"image_url","log_md5",b"log_md5","log_url",b"log_url","show_url",b"show_url","title",b"title","url",b"url","username",b"username","video_id",b"video_id"]) -> None: ...
global___CreativeContent = CreativeContent



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/main/native.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,bilibili/broadcast/message/main/native.proto\x12\x1f\x62ilibili.broadcast.message.main\x1a\x1bgoogle/protobuf/empty.proto\"\\\n\x0fNativePageEvent\x12\x0e\n\x06PageID\x18\x01 \x01(\x03\x12\x39\n\x05Items\x18\x02 \x03(\x0b\x32*.bilibili.broadcast.message.main.EventItem\"m\n\tEventItem\x12\x0e\n\x06ItemID\x18\x01 \x01(\x03\x12\x0c\n\x04Type\x18\x02 \x01(\t\x12\x0b\n\x03Num\x18\x03 \x01(\x03\x12\x12\n\nDisplayNum\x18\x04 \x01(\t\x12\x0e\n\x06WebKey\x18\x05 \x01(\t\x12\x11\n\tdimension\x18\x06 \x01(\x03\x32g\n\nNativePage\x12Y\n\x0bWatchNotify\x12\x16.google.protobuf.Empty\x1a\x30.bilibili.broadcast.message.main.NativePageEvent0\x01\x62\x06proto3')



_NATIVEPAGEEVENT = DESCRIPTOR.message_types_by_name['NativePageEvent']
_EVENTITEM = DESCRIPTOR.message_types_by_name['EventItem']
NativePageEvent = _reflection.GeneratedProtocolMessageType('NativePageEvent', (_message.Message,), {
  'DESCRIPTOR' : _NATIVEPAGEEVENT,
  '__module__' : 'bilibili.broadcast.message.main.native_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.main.NativePageEvent)
  })
_sym_db.RegisterMessage(NativePageEvent)

EventItem = _reflection.GeneratedProtocolMessageType('EventItem', (_message.Message,), {
  'DESCRIPTOR' : _EVENTITEM,
  '__module__' : 'bilibili.broadcast.message.main.native_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.main.EventItem)
  })
_sym_db.RegisterMessage(EventItem)

_NATIVEPAGE = DESCRIPTOR.services_by_name['NativePage']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NATIVEPAGEEVENT._serialized_start=110
  _NATIVEPAGEEVENT._serialized_end=202
  _EVENTITEM._serialized_start=204
  _EVENTITEM._serialized_end=313
  _NATIVEPAGE._serialized_start=315
  _NATIVEPAGE._serialized_end=418
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['bilireq',
 'bilireq.auth',
 'bilireq.bangumi',
 'bilireq.dynamic',
 'bilireq.grpc',
 'bilireq.grpc.dynamic',
 'bilireq.grpc.live',
 'bilireq.grpc.protos.bilibili.account.fission.v1',
 'bilireq.grpc.protos.bilibili.ad.v1',
 'bilireq.grpc.protos.bilibili.api.probe.v1',
 'bilireq.grpc.protos.bilibili.app.archive.middleware.v1',
 'bilireq.grpc.protos.bilibili.app.archive.v1',
 'bilireq.grpc.protos.bilibili.app.card.v1',
 'bilireq.grpc.protos.bilibili.app.dynamic.v1',
 'bilireq.grpc.protos.bilibili.app.dynamic.v2',
 'bilireq.grpc.protos.bilibili.app.interfaces.v1',
 'bilireq.grpc.protos.bilibili.app.listener.v1',
 'bilireq.grpc.protos.bilibili.app.nativeact.v1',
 'bilireq.grpc.protos.bilibili.app.playeronline.v1',
 'bilireq.grpc.protos.bilibili.app.playurl.v1',
 'bilireq.grpc.protos.bilibili.app.resource.privacy.v1',
 'bilireq.grpc.protos.bilibili.app.resource.v1',
 'bilireq.grpc.protos.bilibili.app.show.gateway.v1',
 'bilireq.grpc.protos.bilibili.app.show.popular.v1',
 'bilireq.grpc.protos.bilibili.app.show.rank.v1',
 'bilireq.grpc.protos.bilibili.app.show.region.v1',
 'bilireq.grpc.protos.bilibili.app.space.v1',
 'bilireq.grpc.protos.bilibili.app.splash.v1',
 'bilireq.grpc.protos.bilibili.app.topic.v1',
 'bilireq.grpc.protos.bilibili.app.view.v1',
 'bilireq.grpc.protos.bilibili.app.wall.v1',
 'bilireq.grpc.protos.bilibili.broadcast.message.editor',
 'bilireq.grpc.protos.bilibili.broadcast.message.esports',
 'bilireq.grpc.protos.bilibili.broadcast.message.fission',
 'bilireq.grpc.protos.bilibili.broadcast.message.im',
 'bilireq.grpc.protos.bilibili.broadcast.message.main',
 'bilireq.grpc.protos.bilibili.broadcast.message.note',
 'bilireq.grpc.protos.bilibili.broadcast.message.ogv',
 'bilireq.grpc.protos.bilibili.broadcast.message.ticket',
 'bilireq.grpc.protos.bilibili.broadcast.message.tv',
 'bilireq.grpc.protos.bilibili.broadcast.v1',
 'bilireq.grpc.protos.bilibili.broadcast.v2',
 'bilireq.grpc.protos.bilibili.cheese.gateway.player.v1',
 'bilireq.grpc.protos.bilibili.community.service.dm.v1',
 'bilireq.grpc.protos.bilibili.community.service.govern.v1',
 'bilireq.grpc.protos.bilibili.dynamic.common',
 'bilireq.grpc.protos.bilibili.dynamic.gw',
 'bilireq.grpc.protos.bilibili.dynamic.interfaces.feed.v1',
 'bilireq.grpc.protos.bilibili.gaia.gw',
 'bilireq.grpc.protos.bilibili.im.interfaces.inner_interface.v1',
 'bilireq.grpc.protos.bilibili.im.interfaces.v1',
 'bilireq.grpc.protos.bilibili.im.type',
 'bilireq.grpc.protos.bilibili.live.app.room.v1',
 'bilireq.grpc.protos.bilibili.live.general.interfaces.v1',
 'bilireq.grpc.protos.bilibili.main.common.arch.doll.v1',
 'bilireq.grpc.protos.bilibili.main.community.reply.v1',
 'bilireq.grpc.protos.bilibili.metadata',
 'bilireq.grpc.protos.bilibili.metadata.device',
 'bilireq.grpc.protos.bilibili.metadata.fawkes',
 'bilireq.grpc.protos.bilibili.metadata.locale',
 'bilireq.grpc.protos.bilibili.metadata.network',
 'bilireq.grpc.protos.bilibili.metadata.parabox',
 'bilireq.grpc.protos.bilibili.metadata.restriction',
 'bilireq.grpc.protos.bilibili.pangu.gallery.v1',
 'bilireq.grpc.protos.bilibili.pgc.gateway.player.v1',
 'bilireq.grpc.protos.bilibili.pgc.gateway.player.v2',
 'bilireq.grpc.protos.bilibili.pgc.service.premiere.v1',
 'bilireq.grpc.protos.bilibili.polymer.contract',
 'bilireq.grpc.protos.bilibili.polymer.demo',
 'bilireq.grpc.protos.bilibili.polymer.list',
 'bilireq.grpc.protos.bilibili.rpc',
 'bilireq.grpc.protos.bilibili.tv.interfaces.dm.v1',
 'bilireq.grpc.protos.bilibili.vega.deneb.v1',
 'bilireq.grpc.protos.bilibili.web.interfaces.v1',
 'bilireq.grpc.protos.pgc.biz',
 'bilireq.grpc.protos.pgc.gaetway.vega.v1',
 'bilireq.grpc.utils',
 'bilireq.live',
 'bilireq.login',
 'bilireq.user',
 'bilireq.utils',
 'bilireq.video']

package_data = \
{'': ['*'],
 'bilireq.grpc': ['protos/bilibili/im/interfaces/inner-interface/v1/*']}

install_requires = \
['grpcio>=1.46.3,<2.0.0',
 'httpx>=0.23.0,<0.24.0',
 'protobuf==3.20.1',
 'rsa>=4.8,<5.0']

extras_require = \
{':extra == "qrcode"': ['qrcode[pil]>=7.3.1,<8.0.0']}

setup_kwargs = {
    'name': 'bilireq',
    'version': '0.2.3',
    'description': '',
    'long_description': None,
    'author': 'SK-415',
    'author_email': '2967923486@qq.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _EncryptType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _EncryptTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EncryptType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_ENCRYPT_TYPE: _EncryptType.ValueType  # 0
    """非法值"""

    CLIENT_AES: _EncryptType.ValueType  # 1
    """同客户端人工约定AES加密私钥，存储在客户端"""

    SERVER_RSA_AES: _EncryptType.ValueType  # 2
    """客户端随机生成一个用于AES加密的私钥，并用服务端下发的RSA公钥来加密"""

class EncryptType(_EncryptType, metaclass=_EncryptTypeEnumTypeWrapper):
    """加密方式"""
    pass

INVALID_ENCRYPT_TYPE: EncryptType.ValueType  # 0
"""非法值"""

CLIENT_AES: EncryptType.ValueType  # 1
"""同客户端人工约定AES加密私钥，存储在客户端"""

SERVER_RSA_AES: EncryptType.ValueType  # 2
"""客户端随机生成一个用于AES加密的私钥，并用服务端下发的RSA公钥来加密"""

global___EncryptType = EncryptType


class _PayloadType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _PayloadTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PayloadType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_PAYLOAD: _PayloadType.ValueType  # 0
    """非法值"""

    DEVICE_APP_LIST: _PayloadType.ValueType  # 1
    """设备app列表，对应DeviceAppList"""

class PayloadType(_PayloadType, metaclass=_PayloadTypeEnumTypeWrapper):
    """负载类型"""
    pass

INVALID_PAYLOAD: PayloadType.ValueType  # 0
"""非法值"""

DEVICE_APP_LIST: PayloadType.ValueType  # 1
"""设备app列表，对应DeviceAppList"""

global___PayloadType = PayloadType


class DeviceAppList(google.protobuf.message.Message):
    """待加密的pb对象"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SOURCE_FIELD_NUMBER: builtins.int
    SYSTEM_APP_LIST_FIELD_NUMBER: builtins.int
    USER_APP_LIST_FIELD_NUMBER: builtins.int
    source: typing.Text
    """上报类型
    first_installation:首次安装上报 first_open:每日启动上报
    """

    @property
    def system_app_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """安装的系统程序列表"""
        pass
    @property
    def user_app_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """安装的用户程序列表"""
        pass
    def __init__(self,
        *,
        source: typing.Text = ...,
        system_app_list: typing.Optional[typing.Iterable[typing.Text]] = ...,
        user_app_list: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["source",b"source","system_app_list",b"system_app_list","user_app_list",b"user_app_list"]) -> None: ...
global___DeviceAppList = DeviceAppList

class FetchPublicKeyReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VERSION_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    DEADLINE_FIELD_NUMBER: builtins.int
    version: typing.Text
    """版本号"""

    public_key: typing.Text
    """RSA公钥"""

    deadline: builtins.int
    """公钥过期时间"""

    def __init__(self,
        *,
        version: typing.Text = ...,
        public_key: typing.Text = ...,
        deadline: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deadline",b"deadline","public_key",b"public_key","version",b"version"]) -> None: ...
global___FetchPublicKeyReply = FetchPublicKeyReply

class GaiaDeviceBasicInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PLATFORM_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    APP_ID_FIELD_NUMBER: builtins.int
    SDKVER_FIELD_NUMBER: builtins.int
    APP_VERSION_FIELD_NUMBER: builtins.int
    APP_VERSION_CODE_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    BRAND_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    OSVER_FIELD_NUMBER: builtins.int
    USER_AGENT_FIELD_NUMBER: builtins.int
    BUVID_LOCAL_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    FTS_FIELD_NUMBER: builtins.int
    FIRST_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    platform: typing.Text
    """平台&应用信息
    android/ios/web/h5;
    """

    device: typing.Text
    """运行设备, 用于区分不同的app, 见客户端传入的对应参数。对于苹果系统，device有效值为phone, pad；安卓无法区分phone和pad，留空即可。"""

    mobi_app: typing.Text
    """包类型，用于区分不同的app, 见客户端传入的对应参数（mobi_app ）；对于web端请求，请传空"""

    origin: typing.Text
    """客户端appkey, 用以区分不同的客户端，对应客户端请求参数中的appkey,如果无法获取可传空“”"""

    app_id: typing.Text
    """app产品编号 //产品编号，由数据平台分配，粉=1，白=2，蓝=3，直播姬=4，HD=5，海外=6，OTT=7，漫画=8，TV野版=9，小视频=10，网易漫画=11，网易漫画lite=12，网易漫画HD=13,国际版=14"""

    sdkver: typing.Text
    """应用的版本信息
    SDK版本号   "sdkver": "2.6.6"
    """

    app_version: typing.Text
    """app版本  "app_version":"5.36.0" """

    app_version_code: typing.Text
    """app版本号 "app_version_code":"5360000" """

    build: typing.Text
    """app版本号，见客户端传入的对应参数；对于web端请求，请传空"""

    channel: typing.Text
    """渠道信息
    渠道标识，见客户端传入的对应参数；对于web端请求，请传空；对应chid
    """

    brand: typing.Text
    """机器硬件信息
    手机品牌，见客户端传入的对应参数；
    """

    model: typing.Text
    """手机型号，见客户端传入的对应参数"""

    osver: typing.Text
    """系统版本，见客户端传入的对应参数"""

    user_agent: typing.Text
    buvid_local: typing.Text
    """设备标识信息
    本地设备唯一标识
    """

    buvid: typing.Text
    """设备唯一标识"""

    mid: typing.Text
    """登陆用户信息
    最后一次登陆用户的mid，如果无登陆信息，传0即可
    """

    fts: builtins.int
    """本次启动信息
    app首次启动时间 "fts":1530447775661
    """

    first: builtins.int
    """是否首次启动 是：0 否：1"""

    network: typing.Text
    """网络相关的信息
    网络连接方式, WIFI/CELLULAR/OFFLINE/OTHERNET/ETHERNET "network":"WIFI", ESS_NETWORK_STATE、ACCESS_WIFI_STATE
    """

    def __init__(self,
        *,
        platform: typing.Text = ...,
        device: typing.Text = ...,
        mobi_app: typing.Text = ...,
        origin: typing.Text = ...,
        app_id: typing.Text = ...,
        sdkver: typing.Text = ...,
        app_version: typing.Text = ...,
        app_version_code: typing.Text = ...,
        build: typing.Text = ...,
        channel: typing.Text = ...,
        brand: typing.Text = ...,
        model: typing.Text = ...,
        osver: typing.Text = ...,
        user_agent: typing.Text = ...,
        buvid_local: typing.Text = ...,
        buvid: typing.Text = ...,
        mid: typing.Text = ...,
        fts: builtins.int = ...,
        first: builtins.int = ...,
        network: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id",b"app_id","app_version",b"app_version","app_version_code",b"app_version_code","brand",b"brand","build",b"build","buvid",b"buvid","buvid_local",b"buvid_local","channel",b"channel","device",b"device","first",b"first","fts",b"fts","mid",b"mid","mobi_app",b"mobi_app","model",b"model","network",b"network","origin",b"origin","osver",b"osver","platform",b"platform","sdkver",b"sdkver","user_agent",b"user_agent"]) -> None: ...
global___GaiaDeviceBasicInfo = GaiaDeviceBasicInfo

class GaiaEncryptMsgReq(google.protobuf.message.Message):
    """应用列表上报-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HEADER_FIELD_NUMBER: builtins.int
    ENCRYPT_PAYLOAD_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> global___GaiaMsgHeader:
        """上报头部"""
        pass
    encrypt_payload: builtins.bytes
    """加密数据"""

    def __init__(self,
        *,
        header: typing.Optional[global___GaiaMsgHeader] = ...,
        encrypt_payload: builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["header",b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encrypt_payload",b"encrypt_payload","header",b"header"]) -> None: ...
global___GaiaEncryptMsgReq = GaiaEncryptMsgReq

class GaiaMsgHeader(google.protobuf.message.Message):
    """风控通用消息头"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ENCODE_TYPE_FIELD_NUMBER: builtins.int
    PAYLOAD_TYPE_FIELD_NUMBER: builtins.int
    ENCODED_AES_KEY_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    encode_type: global___EncryptType.ValueType
    """加密类型"""

    payload_type: global___PayloadType.ValueType
    """类型"""

    encoded_aes_key: builtins.bytes
    """RAS加密后的aes_key"""

    ts: builtins.int
    """当前时间戳(ms)"""

    def __init__(self,
        *,
        encode_type: global___EncryptType.ValueType = ...,
        payload_type: global___PayloadType.ValueType = ...,
        encoded_aes_key: builtins.bytes = ...,
        ts: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["encode_type",b"encode_type","encoded_aes_key",b"encoded_aes_key","payload_type",b"payload_type","ts",b"ts"]) -> None: ...
global___GaiaMsgHeader = GaiaMsgHeader

class UploadAppListReply(google.protobuf.message.Message):
    """应用列表上报-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TRACE_ID_FIELD_NUMBER: builtins.int
    trace_id: typing.Text
    """上报响应id"""

    def __init__(self,
        *,
        trace_id: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["trace_id",b"trace_id"]) -> None: ...
global___UploadAppListReply = UploadAppListReply



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Device(google.protobuf.message.Message):
    """设备信息
    gRPC头部:x-bili-device-bin
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    APP_ID_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    MOBI_APP_FIELD_NUMBER: builtins.int
    PLATFORM_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    BRAND_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    OSVER_FIELD_NUMBER: builtins.int
    FP_LOCAL_FIELD_NUMBER: builtins.int
    FP_REMOTE_FIELD_NUMBER: builtins.int
    VERSION_NAME_FIELD_NUMBER: builtins.int
    FP_FIELD_NUMBER: builtins.int
    FTS_FIELD_NUMBER: builtins.int
    app_id: builtins.int
    """产品id
    粉 白 蓝 直播姬 HD 海外 OTT 漫画 TV野版 小视频 网易漫画 网易漫画 网易漫画HD 国际版
    1  2  3    4    5   6    7   8     9     10      11       12       13       14
    """

    build: builtins.int
    """构建id"""

    buvid: typing.Text
    """设备buvid"""

    mobi_app: typing.Text
    """包类型"""

    platform: typing.Text
    """平台类型
    ios android
    """

    device: typing.Text
    """设备类型"""

    channel: typing.Text
    """渠道"""

    brand: typing.Text
    """手机品牌"""

    model: typing.Text
    """手机型号"""

    osver: typing.Text
    """系统版本"""

    fp_local: typing.Text
    """本地设备指纹"""

    fp_remote: typing.Text
    """远程设备指纹"""

    version_name: typing.Text
    """APP版本号"""

    fp: typing.Text
    """设备指纹, 不区分本地或远程设备指纹，作为推送目标的索引"""

    fts: builtins.int
    """"""

    def __init__(self,
        *,
        app_id: builtins.int = ...,
        build: builtins.int = ...,
        buvid: typing.Text = ...,
        mobi_app: typing.Text = ...,
        platform: typing.Text = ...,
        device: typing.Text = ...,
        channel: typing.Text = ...,
        brand: typing.Text = ...,
        model: typing.Text = ...,
        osver: typing.Text = ...,
        fp_local: typing.Text = ...,
        fp_remote: typing.Text = ...,
        version_name: typing.Text = ...,
        fp: typing.Text = ...,
        fts: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_id",b"app_id","brand",b"brand","build",b"build","buvid",b"buvid","channel",b"channel","device",b"device","fp",b"fp","fp_local",b"fp_local","fp_remote",b"fp_remote","fts",b"fts","mobi_app",b"mobi_app","model",b"model","osver",b"osver","platform",b"platform","version_name",b"version_name"]) -> None: ...
global___Device = Device



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PlayViewReq(google.protobuf.message.Message):
    """播放页信息-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EP_ID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    PREFER_CODEC_TYPE_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    ep_id: builtins.int
    """课程epid(与番剧不互通)"""

    cid: builtins.int
    """视频cid"""

    qn: builtins.int
    """清晰度"""

    fnver: builtins.int
    """视频流版本"""

    fnval: builtins.int
    """视频流格式"""

    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """

    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """

    fourk: builtins.bool
    """是否4K"""

    spmid: typing.Text
    """当前页spm"""

    from_spmid: typing.Text
    """上一页spm"""

    teenagers_mode: builtins.int
    """青少年模式"""

    prefer_codec_type: bilibili.app.playurl.v1.playurl_pb2.CodeType.ValueType
    """视频编码"""

    is_preview: builtins.bool
    """是否强制请求预览视频"""

    def __init__(self,
        *,
        ep_id: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: typing.Text = ...,
        from_spmid: typing.Text = ...,
        teenagers_mode: builtins.int = ...,
        prefer_codec_type: bilibili.app.playurl.v1.playurl_pb2.CodeType.ValueType = ...,
        is_preview: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid","download",b"download","ep_id",b"ep_id","fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","fourk",b"fourk","from_spmid",b"from_spmid","is_preview",b"is_preview","prefer_codec_type",b"prefer_codec_type","qn",b"qn","spmid",b"spmid","teenagers_mode",b"teenagers_mode"]) -> None: ...
global___PlayViewReq = PlayViewReq

class ProjectReq(google.protobuf.message.Message):
    """投屏地址-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EP_ID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    FLV_PROJ_FIELD_NUMBER: builtins.int
    ep_id: builtins.int
    """课程epid(与番剧不互通)"""

    cid: builtins.int
    """视频cid"""

    qn: builtins.int
    """清晰度"""

    fnver: builtins.int
    """视频流版本"""

    fnval: builtins.int
    """视频流格式"""

    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """

    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """

    fourk: builtins.bool
    """是否4K"""

    spmid: typing.Text
    """当前页spm"""

    from_spmid: typing.Text
    """上一页spm"""

    protocol: builtins.int
    """投屏协议
    0:默认乐播 1:自建协议 2:云投屏
    """

    device_type: builtins.int
    """投屏设备
    0:默认其他 1:OTT设备
    """

    flv_proj: builtins.bool
    """是否flv格式"""

    def __init__(self,
        *,
        ep_id: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: typing.Text = ...,
        from_spmid: typing.Text = ...,
        protocol: builtins.int = ...,
        device_type: builtins.int = ...,
        flv_proj: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid","device_type",b"device_type","download",b"download","ep_id",b"ep_id","flv_proj",b"flv_proj","fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","fourk",b"fourk","from_spmid",b"from_spmid","protocol",b"protocol","qn",b"qn","spmid",b"spmid"]) -> None: ...
global___ProjectReq = ProjectReq

class PlayViewReply(google.protobuf.message.Message):
    """播放页信息-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VIDEO_INFO_FIELD_NUMBER: builtins.int
    PLAY_CONF_FIELD_NUMBER: builtins.int
    @property
    def video_info(self) -> bilibili.app.playurl.v1.playurl_pb2.VideoInfo:
        """视频url信息"""
        pass
    @property
    def play_conf(self) -> global___PlayAbilityConf:
        """禁用功能配置"""
        pass
    def __init__(self,
        *,
        video_info: typing.Optional[bilibili.app.playurl.v1.playurl_pb2.VideoInfo] = ...,
        play_conf: typing.Optional[global___PlayAbilityConf] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["play_conf",b"play_conf","video_info",b"video_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_conf",b"play_conf","video_info",b"video_info"]) -> None: ...
global___PlayViewReply = PlayViewReply

class PlayAbilityConf(google.protobuf.message.Message):
    """禁用功能配置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BACKGROUND_PLAY_DISABLE_FIELD_NUMBER: builtins.int
    FLIP_DISABLE_FIELD_NUMBER: builtins.int
    CAST_DISABLE_FIELD_NUMBER: builtins.int
    FEEDBACK_DISABLE_FIELD_NUMBER: builtins.int
    SUBTITLE_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_RATE_DISABLE_FIELD_NUMBER: builtins.int
    TIME_UP_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_MODE_DISABLE_FIELD_NUMBER: builtins.int
    SCALE_MODE_DISABLE_FIELD_NUMBER: builtins.int
    LIKE_DISABLE_FIELD_NUMBER: builtins.int
    DISLIKE_DISABLE_FIELD_NUMBER: builtins.int
    COIN_DISABLE_FIELD_NUMBER: builtins.int
    ELEC_DISABLE_FIELD_NUMBER: builtins.int
    SHARE_DISABLE_FIELD_NUMBER: builtins.int
    SCREEN_SHOT_DISABLE_FIELD_NUMBER: builtins.int
    LOCK_SCREEN_DISABLE_FIELD_NUMBER: builtins.int
    RECOMMEND_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_SPEED_DISABLE_FIELD_NUMBER: builtins.int
    DEFINITION_DISABLE_FIELD_NUMBER: builtins.int
    SELECTIONS_DISABLE_FIELD_NUMBER: builtins.int
    NEXT_DISABLE_FIELD_NUMBER: builtins.int
    EDIT_DM_DISABLE_FIELD_NUMBER: builtins.int
    OUTER_DM_DISABLE_FIELD_NUMBER: builtins.int
    INNER_DM_DISABLE_FIELD_NUMBER: builtins.int
    SMALL_WINDOW_DISABLE_FIELD_NUMBER: builtins.int
    background_play_disable: builtins.bool
    """后台播放"""

    flip_disable: builtins.bool
    """镜像反转"""

    cast_disable: builtins.bool
    """支持投屏"""

    feedback_disable: builtins.bool
    """反馈"""

    subtitle_disable: builtins.bool
    """字幕"""

    playback_rate_disable: builtins.bool
    """播放速度"""

    time_up_disable: builtins.bool
    """定时停止播放"""

    playback_mode_disable: builtins.bool
    """播放方式"""

    scale_mode_disable: builtins.bool
    """画面尺寸"""

    like_disable: builtins.bool
    """顶"""

    dislike_disable: builtins.bool
    """踩"""

    coin_disable: builtins.bool
    """投币"""

    elec_disable: builtins.bool
    """充电"""

    share_disable: builtins.bool
    """分享"""

    screen_shot_disable: builtins.bool
    """截图"""

    lock_screen_disable: builtins.bool
    """锁屏"""

    recommend_disable: builtins.bool
    """相关推荐"""

    playback_speed_disable: builtins.bool
    """倍速"""

    definition_disable: builtins.bool
    """清晰度"""

    selections_disable: builtins.bool
    """选集"""

    next_disable: builtins.bool
    """下一集"""

    edit_dm_disable: builtins.bool
    """编辑弹幕"""

    outer_dm_disable: builtins.bool
    """外层面板弹幕设置"""

    inner_dm_disable: builtins.bool
    """三点内弹幕设置"""

    small_window_disable: builtins.bool
    """画中画"""

    def __init__(self,
        *,
        background_play_disable: builtins.bool = ...,
        flip_disable: builtins.bool = ...,
        cast_disable: builtins.bool = ...,
        feedback_disable: builtins.bool = ...,
        subtitle_disable: builtins.bool = ...,
        playback_rate_disable: builtins.bool = ...,
        time_up_disable: builtins.bool = ...,
        playback_mode_disable: builtins.bool = ...,
        scale_mode_disable: builtins.bool = ...,
        like_disable: builtins.bool = ...,
        dislike_disable: builtins.bool = ...,
        coin_disable: builtins.bool = ...,
        elec_disable: builtins.bool = ...,
        share_disable: builtins.bool = ...,
        screen_shot_disable: builtins.bool = ...,
        lock_screen_disable: builtins.bool = ...,
        recommend_disable: builtins.bool = ...,
        playback_speed_disable: builtins.bool = ...,
        definition_disable: builtins.bool = ...,
        selections_disable: builtins.bool = ...,
        next_disable: builtins.bool = ...,
        edit_dm_disable: builtins.bool = ...,
        outer_dm_disable: builtins.bool = ...,
        inner_dm_disable: builtins.bool = ...,
        small_window_disable: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_play_disable",b"background_play_disable","cast_disable",b"cast_disable","coin_disable",b"coin_disable","definition_disable",b"definition_disable","dislike_disable",b"dislike_disable","edit_dm_disable",b"edit_dm_disable","elec_disable",b"elec_disable","feedback_disable",b"feedback_disable","flip_disable",b"flip_disable","inner_dm_disable",b"inner_dm_disable","like_disable",b"like_disable","lock_screen_disable",b"lock_screen_disable","next_disable",b"next_disable","outer_dm_disable",b"outer_dm_disable","playback_mode_disable",b"playback_mode_disable","playback_rate_disable",b"playback_rate_disable","playback_speed_disable",b"playback_speed_disable","recommend_disable",b"recommend_disable","scale_mode_disable",b"scale_mode_disable","screen_shot_disable",b"screen_shot_disable","selections_disable",b"selections_disable","share_disable",b"share_disable","small_window_disable",b"small_window_disable","subtitle_disable",b"subtitle_disable","time_up_disable",b"time_up_disable"]) -> None: ...
global___PlayAbilityConf = PlayAbilityConf

class ProjectReply(google.protobuf.message.Message):
    """投屏地址-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROJECT_FIELD_NUMBER: builtins.int
    @property
    def project(self) -> bilibili.app.playurl.v1.playurl_pb2.PlayURLReply: ...
    def __init__(self,
        *,
        project: typing.Optional[bilibili.app.playurl.v1.playurl_pb2.PlayURLReply] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["project",b"project"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["project",b"project"]) -> None: ...
global___ProjectReply = ProjectReply



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/v1/broadcast.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilireq.grpc.protos.bilibili.rpc import status_pb2 as bilibili_dot_rpc_dot_status__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/broadcast/v1/broadcast.proto\x12\x15\x62ilibili.broadcast.v1\x1a\x19\x62ilibili/rpc/status.proto\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\"=\n\x07\x41uthReq\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0f\n\x07\x63onn_id\x18\x02 \x01(\t\x12\x13\n\x0blast_msg_id\x18\x03 \x01(\x03\"\n\n\x08\x41uthResp\"~\n\x0e\x42roadcastFrame\x12\x33\n\x07options\x18\x01 \x01(\x0b\x32\".bilibili.broadcast.v1.FrameOption\x12\x13\n\x0btarget_path\x18\x02 \x01(\t\x12\"\n\x04\x62ody\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"\x90\x01\n\x0b\x46rameOption\x12\x12\n\nmessage_id\x18\x01 \x01(\x03\x12\x10\n\x08sequence\x18\x02 \x01(\x03\x12\x0e\n\x06is_ack\x18\x03 \x01(\x08\x12$\n\x06status\x18\x04 \x01(\x0b\x32\x14.bilibili.rpc.Status\x12\x12\n\nack_origin\x18\x05 \x01(\t\x12\x11\n\ttimestamp\x18\x06 \x01(\x03\"\x0e\n\x0cHeartbeatReq\"\x0f\n\rHeartbeatResp\"H\n\rMessageAckReq\x12\x0e\n\x06\x61\x63k_id\x18\x01 \x01(\x03\x12\x12\n\nack_origin\x18\x02 \x01(\t\x12\x13\n\x0btarget_path\x18\x03 \x01(\t\"\"\n\nTargetPath\x12\x14\n\x0ctarget_paths\x18\x01 \x03(\t*-\n\x06\x41\x63tion\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06UPDATE\x10\x01\x12\n\n\x06\x44\x45LETE\x10\x02\x32\x8a\x03\n\tBroadcast\x12G\n\x04\x41uth\x12\x1e.bilibili.broadcast.v1.AuthReq\x1a\x1f.bilibili.broadcast.v1.AuthResp\x12V\n\tHeartbeat\x12#.bilibili.broadcast.v1.HeartbeatReq\x1a$.bilibili.broadcast.v1.HeartbeatResp\x12\x46\n\tSubscribe\x12!.bilibili.broadcast.v1.TargetPath\x1a\x16.google.protobuf.Empty\x12H\n\x0bUnsubscribe\x12!.bilibili.broadcast.v1.TargetPath\x1a\x16.google.protobuf.Empty\x12J\n\nMessageAck\x12$.bilibili.broadcast.v1.MessageAckReq\x1a\x16.google.protobuf.Empty2s\n\x0f\x42roadcastTunnel\x12`\n\x0c\x43reateTunnel\x12%.bilibili.broadcast.v1.BroadcastFrame\x1a%.bilibili.broadcast.v1.BroadcastFrame(\x01\x30\x01\x62\x06proto3')

_ACTION = DESCRIPTOR.enum_types_by_name['Action']
Action = enum_type_wrapper.EnumTypeWrapper(_ACTION)
UNKNOWN = 0
UPDATE = 1
DELETE = 2


_AUTHREQ = DESCRIPTOR.message_types_by_name['AuthReq']
_AUTHRESP = DESCRIPTOR.message_types_by_name['AuthResp']
_BROADCASTFRAME = DESCRIPTOR.message_types_by_name['BroadcastFrame']
_FRAMEOPTION = DESCRIPTOR.message_types_by_name['FrameOption']
_HEARTBEATREQ = DESCRIPTOR.message_types_by_name['HeartbeatReq']
_HEARTBEATRESP = DESCRIPTOR.message_types_by_name['HeartbeatResp']
_MESSAGEACKREQ = DESCRIPTOR.message_types_by_name['MessageAckReq']
_TARGETPATH = DESCRIPTOR.message_types_by_name['TargetPath']
AuthReq = _reflection.GeneratedProtocolMessageType('AuthReq', (_message.Message,), {
  'DESCRIPTOR' : _AUTHREQ,
  '__module__' : 'bilibili.broadcast.v1.broadcast_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.AuthReq)
  })
_sym_db.RegisterMessage(AuthReq)

AuthResp = _reflection.GeneratedProtocolMessageType('AuthResp', (_message.Message,), {
  'DESCRIPTOR' : _AUTHRESP,
  '__module__' : 'bilibili.broadcast.v1.broadcast_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.AuthResp)
  })
_sym_db.RegisterMessage(AuthResp)

BroadcastFrame = _reflection.GeneratedProtocolMessageType('BroadcastFrame', (_message.Message,), {
  'DESCRIPTOR' : _BROADCASTFRAME,
  '__module__' : 'bilibili.broadcast.v1.broadcast_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.BroadcastFrame)
  })
_sym_db.RegisterMessage(BroadcastFrame)

FrameOption = _reflection.GeneratedProtocolMessageType('FrameOption', (_message.Message,), {
  'DESCRIPTOR' : _FRAMEOPTION,
  '__module__' : 'bilibili.broadcast.v1.broadcast_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.FrameOption)
  })
_sym_db.RegisterMessage(FrameOption)

HeartbeatReq = _reflection.GeneratedProtocolMessageType('HeartbeatReq', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATREQ,
  '__module__' : 'bilibili.broadcast.v1.broadcast_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.HeartbeatReq)
  })
_sym_db.RegisterMessage(HeartbeatReq)

HeartbeatResp = _reflection.GeneratedProtocolMessageType('HeartbeatResp', (_message.Message,), {
  'DESCRIPTOR' : _HEARTBEATRESP,
  '__module__' : 'bilibili.broadcast.v1.broadcast_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.HeartbeatResp)
  })
_sym_db.RegisterMessage(HeartbeatResp)

MessageAckReq = _reflection.GeneratedProtocolMessageType('MessageAckReq', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEACKREQ,
  '__module__' : 'bilibili.broadcast.v1.broadcast_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.MessageAckReq)
  })
_sym_db.RegisterMessage(MessageAckReq)

TargetPath = _reflection.GeneratedProtocolMessageType('TargetPath', (_message.Message,), {
  'DESCRIPTOR' : _TARGETPATH,
  '__module__' : 'bilibili.broadcast.v1.broadcast_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.TargetPath)
  })
_sym_db.RegisterMessage(TargetPath)

_BROADCAST = DESCRIPTOR.services_by_name['Broadcast']
_BROADCASTTUNNEL = DESCRIPTOR.services_by_name['BroadcastTunnel']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ACTION._serialized_start=640
  _ACTION._serialized_end=685
  _AUTHREQ._serialized_start=147
  _AUTHREQ._serialized_end=208
  _AUTHRESP._serialized_start=210
  _AUTHRESP._serialized_end=220
  _BROADCASTFRAME._serialized_start=222
  _BROADCASTFRAME._serialized_end=348
  _FRAMEOPTION._serialized_start=351
  _FRAMEOPTION._serialized_end=495
  _HEARTBEATREQ._serialized_start=497
  _HEARTBEATREQ._serialized_end=511
  _HEARTBEATRESP._serialized_start=513
  _HEARTBEATRESP._serialized_end=528
  _MESSAGEACKREQ._serialized_start=530
  _MESSAGEACKREQ._serialized_end=602
  _TARGETPATH._serialized_start=604
  _TARGETPATH._serialized_end=638
  _BROADCAST._serialized_start=688
  _BROADCAST._serialized_end=1082
  _BROADCASTTUNNEL._serialized_start=1084
  _BROADCASTTUNNEL._serialized_end=1199
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/metadata/locale/locale.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%bilibili/metadata/locale/locale.proto\x12\x18\x62ilibili.metadata.locale\"\x9a\x01\n\x06Locale\x12\x35\n\x08\x63_locale\x18\x01 \x01(\x0b\x32#.bilibili.metadata.locale.LocaleIds\x12\x35\n\x08s_locale\x18\x02 \x01(\x0b\x32#.bilibili.metadata.locale.LocaleIds\x12\x10\n\x08sim_code\x18\x03 \x01(\t\x12\x10\n\x08timezone\x18\x04 \x01(\t\"=\n\tLocaleIds\x12\x10\n\x08language\x18\x01 \x01(\t\x12\x0e\n\x06script\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\tb\x06proto3')



_LOCALE = DESCRIPTOR.message_types_by_name['Locale']
_LOCALEIDS = DESCRIPTOR.message_types_by_name['LocaleIds']
Locale = _reflection.GeneratedProtocolMessageType('Locale', (_message.Message,), {
  'DESCRIPTOR' : _LOCALE,
  '__module__' : 'bilibili.metadata.locale.locale_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.metadata.locale.Locale)
  })
_sym_db.RegisterMessage(Locale)

LocaleIds = _reflection.GeneratedProtocolMessageType('LocaleIds', (_message.Message,), {
  'DESCRIPTOR' : _LOCALEIDS,
  '__module__' : 'bilibili.metadata.locale.locale_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.metadata.locale.LocaleIds)
  })
_sym_db.RegisterMessage(LocaleIds)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOCALE._serialized_start=68
  _LOCALE._serialized_end=222
  _LOCALEIDS._serialized_start=224
  _LOCALEIDS._serialized_end=285
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/message/tv/proj.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(bilibili/broadcast/message/tv/proj.proto\x12\x1d\x62ilibili.broadcast.message.tv\x1a\x1bgoogle/protobuf/empty.proto\"\x9a\x01\n\tProjReply\x12\x10\n\x08\x63md_type\x18\x01 \x01(\x03\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0b\n\x03\x61id\x18\x03 \x01(\x03\x12\x0b\n\x03\x63id\x18\x04 \x01(\x03\x12\x12\n\nvideo_type\x18\x05 \x01(\x03\x12\r\n\x05\x65p_id\x18\x06 \x01(\x03\x12\x11\n\tseason_id\x18\x07 \x01(\x03\x12\x0f\n\x07seek_ts\x18\x08 \x01(\x03\x12\r\n\x05\x65xtra\x18\t \x01(\t\"<\n\x10LiveStatusNotify\x12\x0e\n\x06status\x18\x01 \x01(\x03\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\x03\"\x1c\n\rEsportsNotify\x12\x0b\n\x03\x63id\x18\x01 \x01(\x03\"H\n\x0fPublicityNotify\x12\x14\n\x0cpublicity_id\x18\x01 \x01(\x03\x12\x0f\n\x07room_id\x18\x02 \x01(\x03\x12\x0e\n\x06status\x18\x03 \x01(\x03\"!\n\x0eLiveSkipNotify\x12\x0f\n\x07live_id\x18\x01 \x01(\x03\x32\xa8\x03\n\x02Tv\x12J\n\x04Proj\x12\x16.google.protobuf.Empty\x1a(.bilibili.broadcast.message.tv.ProjReply0\x01\x12W\n\nLiveStatus\x12\x16.google.protobuf.Empty\x1a/.bilibili.broadcast.message.tv.LiveStatusNotify0\x01\x12Q\n\x07\x45sports\x12\x16.google.protobuf.Empty\x1a,.bilibili.broadcast.message.tv.EsportsNotify0\x01\x12U\n\tPublicity\x12\x16.google.protobuf.Empty\x1a..bilibili.broadcast.message.tv.PublicityNotify0\x01\x12S\n\x08LiveSkip\x12\x16.google.protobuf.Empty\x1a-.bilibili.broadcast.message.tv.LiveSkipNotify0\x01\x62\x06proto3')



_PROJREPLY = DESCRIPTOR.message_types_by_name['ProjReply']
_LIVESTATUSNOTIFY = DESCRIPTOR.message_types_by_name['LiveStatusNotify']
_ESPORTSNOTIFY = DESCRIPTOR.message_types_by_name['EsportsNotify']
_PUBLICITYNOTIFY = DESCRIPTOR.message_types_by_name['PublicityNotify']
_LIVESKIPNOTIFY = DESCRIPTOR.message_types_by_name['LiveSkipNotify']
ProjReply = _reflection.GeneratedProtocolMessageType('ProjReply', (_message.Message,), {
  'DESCRIPTOR' : _PROJREPLY,
  '__module__' : 'bilibili.broadcast.message.tv.proj_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.tv.ProjReply)
  })
_sym_db.RegisterMessage(ProjReply)

LiveStatusNotify = _reflection.GeneratedProtocolMessageType('LiveStatusNotify', (_message.Message,), {
  'DESCRIPTOR' : _LIVESTATUSNOTIFY,
  '__module__' : 'bilibili.broadcast.message.tv.proj_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.tv.LiveStatusNotify)
  })
_sym_db.RegisterMessage(LiveStatusNotify)

EsportsNotify = _reflection.GeneratedProtocolMessageType('EsportsNotify', (_message.Message,), {
  'DESCRIPTOR' : _ESPORTSNOTIFY,
  '__module__' : 'bilibili.broadcast.message.tv.proj_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.tv.EsportsNotify)
  })
_sym_db.RegisterMessage(EsportsNotify)

PublicityNotify = _reflection.GeneratedProtocolMessageType('PublicityNotify', (_message.Message,), {
  'DESCRIPTOR' : _PUBLICITYNOTIFY,
  '__module__' : 'bilibili.broadcast.message.tv.proj_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.tv.PublicityNotify)
  })
_sym_db.RegisterMessage(PublicityNotify)

LiveSkipNotify = _reflection.GeneratedProtocolMessageType('LiveSkipNotify', (_message.Message,), {
  'DESCRIPTOR' : _LIVESKIPNOTIFY,
  '__module__' : 'bilibili.broadcast.message.tv.proj_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.message.tv.LiveSkipNotify)
  })
_sym_db.RegisterMessage(LiveSkipNotify)

_TV = DESCRIPTOR.services_by_name['Tv']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROJREPLY._serialized_start=105
  _PROJREPLY._serialized_end=259
  _LIVESTATUSNOTIFY._serialized_start=261
  _LIVESTATUSNOTIFY._serialized_end=321
  _ESPORTSNOTIFY._serialized_start=323
  _ESPORTSNOTIFY._serialized_end=351
  _PUBLICITYNOTIFY._serialized_start=353
  _PUBLICITYNOTIFY._serialized_end=425
  _LIVESKIPNOTIFY._serialized_start=427
  _LIVESKIPNOTIFY._serialized_end=460
  _TV._serialized_start=463
  _TV._serialized_end=887
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.app.playurl.v1.playurl_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class BusinessInfo(google.protobuf.message.Message):
    """其他业务信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    BP_FIELD_NUMBER: builtins.int
    MARLIN_TOKEN_FIELD_NUMBER: builtins.int
    is_preview: builtins.bool
    """当前视频是否是预览"""

    bp: builtins.bool
    """用户是否承包过"""

    marlin_token: typing.Text
    """drm使用"""

    def __init__(self,
        *,
        is_preview: builtins.bool = ...,
        bp: builtins.bool = ...,
        marlin_token: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bp",b"bp","is_preview",b"is_preview","marlin_token",b"marlin_token"]) -> None: ...
global___BusinessInfo = BusinessInfo

class Event(google.protobuf.message.Message):
    """事件"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SHAKE_FIELD_NUMBER: builtins.int
    @property
    def shake(self) -> global___Shake:
        """震动"""
        pass
    def __init__(self,
        *,
        shake: typing.Optional[global___Shake] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["shake",b"shake"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["shake",b"shake"]) -> None: ...
global___Event = Event

class LivePlayInfo(google.protobuf.message.Message):
    """播放信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CURRENT_QN_FIELD_NUMBER: builtins.int
    QUALITY_DESCRIPTION_FIELD_NUMBER: builtins.int
    DURL_FIELD_NUMBER: builtins.int
    current_qn: builtins.int
    """"""

    @property
    def quality_description(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QualityDescription]:
        """"""
        pass
    @property
    def durl(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResponseDataUrl]:
        """"""
        pass
    def __init__(self,
        *,
        current_qn: builtins.int = ...,
        quality_description: typing.Optional[typing.Iterable[global___QualityDescription]] = ...,
        durl: typing.Optional[typing.Iterable[global___ResponseDataUrl]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["current_qn",b"current_qn","durl",b"durl","quality_description",b"quality_description"]) -> None: ...
global___LivePlayInfo = LivePlayInfo

class LivePlayViewReply(google.protobuf.message.Message):
    """直播播放页信息-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROOM_INFO_FIELD_NUMBER: builtins.int
    PLAY_INFO_FIELD_NUMBER: builtins.int
    @property
    def room_info(self) -> global___RoomInfo:
        """房间信息"""
        pass
    @property
    def play_info(self) -> global___LivePlayInfo:
        """播放信息"""
        pass
    def __init__(self,
        *,
        room_info: typing.Optional[global___RoomInfo] = ...,
        play_info: typing.Optional[global___LivePlayInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["play_info",b"play_info","room_info",b"room_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_info",b"play_info","room_info",b"room_info"]) -> None: ...
global___LivePlayViewReply = LivePlayViewReply

class LivePlayViewReq(google.protobuf.message.Message):
    """直播播放页信息-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EP_ID_FIELD_NUMBER: builtins.int
    QUALITY_FIELD_NUMBER: builtins.int
    PTYPE_FIELD_NUMBER: builtins.int
    HTTPS_FIELD_NUMBER: builtins.int
    PLAY_TYPE_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    ep_id: builtins.int
    """剧集epid"""

    quality: builtins.int
    """清晰度
    0,10000:原画 400:蓝光 250:超清 150:高清 80:流畅
    """

    ptype: builtins.int
    """类型
    0:音频 2:hevc 4:dash 8:p2p, 16:蒙版
    """

    https: builtins.bool
    """是否请求https"""

    play_type: builtins.int
    """0:默认直播间播放 1:投屏播放"""

    device_type: builtins.int
    """投屏设备
    0:默认其他 1:OTT设备
    """

    def __init__(self,
        *,
        ep_id: builtins.int = ...,
        quality: builtins.int = ...,
        ptype: builtins.int = ...,
        https: builtins.bool = ...,
        play_type: builtins.int = ...,
        device_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_type",b"device_type","ep_id",b"ep_id","https",b"https","play_type",b"play_type","ptype",b"ptype","quality",b"quality"]) -> None: ...
global___LivePlayViewReq = LivePlayViewReq

class PlayAbilityConf(google.protobuf.message.Message):
    """禁用功能配置"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BACKGROUND_PLAY_DISABLE_FIELD_NUMBER: builtins.int
    FLIP_DISABLE_FIELD_NUMBER: builtins.int
    CAST_DISABLE_FIELD_NUMBER: builtins.int
    FEEDBACK_DISABLE_FIELD_NUMBER: builtins.int
    SUBTITLE_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_RATE_DISABLE_FIELD_NUMBER: builtins.int
    TIME_UP_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_MODE_DISABLE_FIELD_NUMBER: builtins.int
    SCALE_MODE_DISABLE_FIELD_NUMBER: builtins.int
    LIKE_DISABLE_FIELD_NUMBER: builtins.int
    DISLIKE_DISABLE_FIELD_NUMBER: builtins.int
    COIN_DISABLE_FIELD_NUMBER: builtins.int
    ELEC_DISABLE_FIELD_NUMBER: builtins.int
    SHARE_DISABLE_FIELD_NUMBER: builtins.int
    SCREEN_SHOT_DISABLE_FIELD_NUMBER: builtins.int
    LOCK_SCREEN_DISABLE_FIELD_NUMBER: builtins.int
    RECOMMEND_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_SPEED_DISABLE_FIELD_NUMBER: builtins.int
    DEFINITION_DISABLE_FIELD_NUMBER: builtins.int
    SELECTIONS_DISABLE_FIELD_NUMBER: builtins.int
    NEXT_DISABLE_FIELD_NUMBER: builtins.int
    EDIT_DM_DISABLE_FIELD_NUMBER: builtins.int
    SMALL_WINDOW_DISABLE_FIELD_NUMBER: builtins.int
    SHAKE_DISABLE_FIELD_NUMBER: builtins.int
    OUTER_DM_DISABLE_FIELD_NUMBER: builtins.int
    INNER_DM_DISABLE_FIELD_NUMBER: builtins.int
    FREYA_ENTER_DISABLE_FIELD_NUMBER: builtins.int
    DOLBY_DISABLE_FIELD_NUMBER: builtins.int
    FREYA_FULL_DISABLE_FIELD_NUMBER: builtins.int
    SKIP_OPED_SWITCH_DISABLE_FIELD_NUMBER: builtins.int
    background_play_disable: builtins.bool
    """后台播放"""

    flip_disable: builtins.bool
    """镜像反转"""

    cast_disable: builtins.bool
    """投屏"""

    feedback_disable: builtins.bool
    """反馈"""

    subtitle_disable: builtins.bool
    """字幕"""

    playback_rate_disable: builtins.bool
    """播放速度"""

    time_up_disable: builtins.bool
    """定时停止"""

    playback_mode_disable: builtins.bool
    """播放方式"""

    scale_mode_disable: builtins.bool
    """画面尺寸"""

    like_disable: builtins.bool
    """赞"""

    dislike_disable: builtins.bool
    """踩"""

    coin_disable: builtins.bool
    """投币"""

    elec_disable: builtins.bool
    """充电"""

    share_disable: builtins.bool
    """分享"""

    screen_shot_disable: builtins.bool
    """截图"""

    lock_screen_disable: builtins.bool
    """锁定"""

    recommend_disable: builtins.bool
    """相关推荐"""

    playback_speed_disable: builtins.bool
    """播放速度"""

    definition_disable: builtins.bool
    """清晰度"""

    selections_disable: builtins.bool
    """选集"""

    next_disable: builtins.bool
    """下一集"""

    edit_dm_disable: builtins.bool
    """编辑弹幕"""

    small_window_disable: builtins.bool
    """小窗"""

    shake_disable: builtins.bool
    """震动"""

    outer_dm_disable: builtins.bool
    """外层面板弹幕设置"""

    inner_dm_disable: builtins.bool
    """三点内弹幕设置"""

    freya_enter_disable: builtins.bool
    """一起看入口"""

    dolby_disable: builtins.bool
    """杜比音效"""

    freya_full_disable: builtins.bool
    """全屏一起看入口"""

    skip_oped_switch_disable: builtins.bool
    """"""

    def __init__(self,
        *,
        background_play_disable: builtins.bool = ...,
        flip_disable: builtins.bool = ...,
        cast_disable: builtins.bool = ...,
        feedback_disable: builtins.bool = ...,
        subtitle_disable: builtins.bool = ...,
        playback_rate_disable: builtins.bool = ...,
        time_up_disable: builtins.bool = ...,
        playback_mode_disable: builtins.bool = ...,
        scale_mode_disable: builtins.bool = ...,
        like_disable: builtins.bool = ...,
        dislike_disable: builtins.bool = ...,
        coin_disable: builtins.bool = ...,
        elec_disable: builtins.bool = ...,
        share_disable: builtins.bool = ...,
        screen_shot_disable: builtins.bool = ...,
        lock_screen_disable: builtins.bool = ...,
        recommend_disable: builtins.bool = ...,
        playback_speed_disable: builtins.bool = ...,
        definition_disable: builtins.bool = ...,
        selections_disable: builtins.bool = ...,
        next_disable: builtins.bool = ...,
        edit_dm_disable: builtins.bool = ...,
        small_window_disable: builtins.bool = ...,
        shake_disable: builtins.bool = ...,
        outer_dm_disable: builtins.bool = ...,
        inner_dm_disable: builtins.bool = ...,
        freya_enter_disable: builtins.bool = ...,
        dolby_disable: builtins.bool = ...,
        freya_full_disable: builtins.bool = ...,
        skip_oped_switch_disable: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_play_disable",b"background_play_disable","cast_disable",b"cast_disable","coin_disable",b"coin_disable","definition_disable",b"definition_disable","dislike_disable",b"dislike_disable","dolby_disable",b"dolby_disable","edit_dm_disable",b"edit_dm_disable","elec_disable",b"elec_disable","feedback_disable",b"feedback_disable","flip_disable",b"flip_disable","freya_enter_disable",b"freya_enter_disable","freya_full_disable",b"freya_full_disable","inner_dm_disable",b"inner_dm_disable","like_disable",b"like_disable","lock_screen_disable",b"lock_screen_disable","next_disable",b"next_disable","outer_dm_disable",b"outer_dm_disable","playback_mode_disable",b"playback_mode_disable","playback_rate_disable",b"playback_rate_disable","playback_speed_disable",b"playback_speed_disable","recommend_disable",b"recommend_disable","scale_mode_disable",b"scale_mode_disable","screen_shot_disable",b"screen_shot_disable","selections_disable",b"selections_disable","shake_disable",b"shake_disable","share_disable",b"share_disable","skip_oped_switch_disable",b"skip_oped_switch_disable","small_window_disable",b"small_window_disable","subtitle_disable",b"subtitle_disable","time_up_disable",b"time_up_disable"]) -> None: ...
global___PlayAbilityConf = PlayAbilityConf

class PlayViewReply(google.protobuf.message.Message):
    """ 播放页信息-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VIDEO_INFO_FIELD_NUMBER: builtins.int
    PLAY_CONF_FIELD_NUMBER: builtins.int
    BUSINESS_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    @property
    def video_info(self) -> bilibili.app.playurl.v1.playurl_pb2.VideoInfo:
        """视频流信息"""
        pass
    @property
    def play_conf(self) -> global___PlayAbilityConf:
        """播放控件用户自定义配置"""
        pass
    @property
    def business(self) -> global___BusinessInfo:
        """业务需要的其他信息"""
        pass
    @property
    def event(self) -> global___Event:
        """事件"""
        pass
    def __init__(self,
        *,
        video_info: typing.Optional[bilibili.app.playurl.v1.playurl_pb2.VideoInfo] = ...,
        play_conf: typing.Optional[global___PlayAbilityConf] = ...,
        business: typing.Optional[global___BusinessInfo] = ...,
        event: typing.Optional[global___Event] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["business",b"business","event",b"event","play_conf",b"play_conf","video_info",b"video_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business",b"business","event",b"event","play_conf",b"play_conf","video_info",b"video_info"]) -> None: ...
global___PlayViewReply = PlayViewReply

class PlayViewReq(google.protobuf.message.Message):
    """播放页信息-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EPID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    PREFER_CODEC_TYPE_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    epid: builtins.int
    """剧集epid"""

    cid: builtins.int
    """视频cid"""

    qn: builtins.int
    """清晰度"""

    fnver: builtins.int
    """视频流版本"""

    fnval: builtins.int
    """视频流格式"""

    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """

    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """

    fourk: builtins.bool
    """是否4K"""

    spmid: typing.Text
    """当前页spm"""

    from_spmid: typing.Text
    """上一页spm"""

    teenagers_mode: builtins.int
    """青少年模式"""

    prefer_codec_type: bilibili.app.playurl.v1.playurl_pb2.CodeType.ValueType
    """视频编码"""

    is_preview: builtins.bool
    """是否强制请求预览视频"""

    room_id: builtins.int
    """一起看房间id"""

    def __init__(self,
        *,
        epid: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: typing.Text = ...,
        from_spmid: typing.Text = ...,
        teenagers_mode: builtins.int = ...,
        prefer_codec_type: bilibili.app.playurl.v1.playurl_pb2.CodeType.ValueType = ...,
        is_preview: builtins.bool = ...,
        room_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid","download",b"download","epid",b"epid","fnval",b"fnval","fnver",b"fnver","force_host",b"force_host","fourk",b"fourk","from_spmid",b"from_spmid","is_preview",b"is_preview","prefer_codec_type",b"prefer_codec_type","qn",b"qn","room_id",b"room_id","spmid",b"spmid","teenagers_mode",b"teenagers_mode"]) -> None: ...
global___PlayViewReq = PlayViewReq

class ProjectReply(google.protobuf.message.Message):
    """投屏地址-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROJECT_FIELD_NUMBER: builtins.int
    @property
    def project(self) -> bilibili.app.playurl.v1.playurl_pb2.PlayURLReply: ...
    def __init__(self,
        *,
        project: typing.Optional[bilibili.app.playurl.v1.playurl_pb2.PlayURLReply] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["project",b"project"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["project",b"project"]) -> None: ...
global___ProjectReply = ProjectReply

class ProjectReq(google.protobuf.message.Message):
    """投屏地址-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EP_ID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCEHOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROMSPMID_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    USE_NEW_PROJECT_CODE_FIELD_NUMBER: builtins.int
    ep_id: builtins.int
    """剧集epid"""

    cid: builtins.int
    """视频cid"""

    qn: builtins.int
    """清晰度"""

    fnver: builtins.int
    """视频流版本"""

    fnval: builtins.int
    """视频流格式"""

    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """

    forceHost: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """

    fourk: builtins.bool
    """是否4K"""

    spmid: typing.Text
    """当前页spm"""

    fromSpmid: typing.Text
    """上一页spm"""

    protocol: builtins.int
    """使用协议
    0:默认乐播 1:自建协议 2:云投屏 3:airplay
    """

    device_type: builtins.int
    """投屏设备
    0:默认其他 1:OTT设备
    """

    use_new_project_code: builtins.bool
    """"""

    def __init__(self,
        *,
        ep_id: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        forceHost: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: typing.Text = ...,
        fromSpmid: typing.Text = ...,
        protocol: builtins.int = ...,
        device_type: builtins.int = ...,
        use_new_project_code: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid",b"cid","device_type",b"device_type","download",b"download","ep_id",b"ep_id","fnval",b"fnval","fnver",b"fnver","forceHost",b"forceHost","fourk",b"fourk","fromSpmid",b"fromSpmid","protocol",b"protocol","qn",b"qn","spmid",b"spmid","use_new_project_code",b"use_new_project_code"]) -> None: ...
global___ProjectReq = ProjectReq

class QualityDescription(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    QN_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    qn: builtins.int
    """"""

    desc: typing.Text
    """"""

    def __init__(self,
        *,
        qn: builtins.int = ...,
        desc: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc",b"desc","qn",b"qn"]) -> None: ...
global___QualityDescription = QualityDescription

class ResponseDataUrl(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    URL_FIELD_NUMBER: builtins.int
    STREAM_TYPE_FIELD_NUMBER: builtins.int
    PTAG_FIELD_NUMBER: builtins.int
    url: typing.Text
    stream_type: builtins.int
    """表示stream类型,按位表示
    Value|  1   |  1  |  1   |  1   |     1
    --------------------------------------------
    desc | mask | p2p | dash | hevc | only-audio
    """

    ptag: builtins.int
    """表示支持p2p的cdn厂商,按位表示
    值   | 1  |  1  |  1  | 1  |  1  | 1  | 1  | 1
    -----------------------------------------------
    CDN	| hw | bdy | bsy | ws | txy | qn | js | bvc
    """

    def __init__(self,
        *,
        url: typing.Text = ...,
        stream_type: builtins.int = ...,
        ptag: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ptag",b"ptag","stream_type",b"stream_type","url",b"url"]) -> None: ...
global___ResponseDataUrl = ResponseDataUrl

class RoomInfo(google.protobuf.message.Message):
    """房间信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ROOM_ID_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SHOW_FIELD_NUMBER: builtins.int
    room_id: builtins.int
    """房间长号"""

    uid: builtins.int
    """主播mid"""

    @property
    def status(self) -> global___RoomStatusInfo:
        """状态相关"""
        pass
    @property
    def show(self) -> global___RoomShowInfo:
        """展示相关"""
        pass
    def __init__(self,
        *,
        room_id: builtins.int = ...,
        uid: builtins.int = ...,
        status: typing.Optional[global___RoomStatusInfo] = ...,
        show: typing.Optional[global___RoomShowInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["show",b"show","status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["room_id",b"room_id","show",b"show","status",b"status","uid",b"uid"]) -> None: ...
global___RoomInfo = RoomInfo

class RoomShowInfo(google.protobuf.message.Message):
    """房间信息-展示相关"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SHORT_ID_FIELD_NUMBER: builtins.int
    POPULARITY_COUNT_FIELD_NUMBER: builtins.int
    LIVE_START_TIME_FIELD_NUMBER: builtins.int
    short_id: builtins.int
    """短号"""

    popularity_count: builtins.int
    """人气值"""

    live_start_time: builtins.int
    """最近一次开播时间戳"""

    def __init__(self,
        *,
        short_id: builtins.int = ...,
        popularity_count: builtins.int = ...,
        live_start_time: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["live_start_time",b"live_start_time","popularity_count",b"popularity_count","short_id",b"short_id"]) -> None: ...
global___RoomShowInfo = RoomShowInfo

class RoomStatusInfo(google.protobuf.message.Message):
    """房间信息-状态相关"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LIVE_STATUS_FIELD_NUMBER: builtins.int
    LIVE_SCREEN_TYPE_FIELD_NUMBER: builtins.int
    LIVE_MARK_FIELD_NUMBER: builtins.int
    LOCK_STATUS_FIELD_NUMBER: builtins.int
    LOCK_TIME_FIELD_NUMBER: builtins.int
    HIDDEN_STATUS_FIELD_NUMBER: builtins.int
    HIDDEN_TIME_FIELD_NUMBER: builtins.int
    LIVE_TYPE_FIELD_NUMBER: builtins.int
    ROOM_SHIELD_FIELD_NUMBER: builtins.int
    live_status: builtins.int
    """直播间状态
    0:未开播 1:直播中 2:轮播中
    """

    live_screen_type: builtins.int
    """横竖屏方向
    0:横屏 1:竖屏
    """

    live_mark: builtins.int
    """是否开播过标识"""

    lock_status: builtins.int
    """封禁状态
    0:未封禁 1:审核封禁 2:全网封禁
    """

    lock_time: builtins.int
    """封禁时间戳"""

    hidden_status: builtins.int
    """隐藏状态
    0:不隐藏 1:隐藏
    """

    hidden_time: builtins.int
    """隐藏时间戳"""

    live_type: builtins.int
    """直播类型
    0:默认 1:摄像头直播 2;录屏直播 3:语音直播
    """

    room_shield: builtins.int
    """"""

    def __init__(self,
        *,
        live_status: builtins.int = ...,
        live_screen_type: builtins.int = ...,
        live_mark: builtins.int = ...,
        lock_status: builtins.int = ...,
        lock_time: builtins.int = ...,
        hidden_status: builtins.int = ...,
        hidden_time: builtins.int = ...,
        live_type: builtins.int = ...,
        room_shield: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hidden_status",b"hidden_status","hidden_time",b"hidden_time","live_mark",b"live_mark","live_screen_type",b"live_screen_type","live_status",b"live_status","live_type",b"live_type","lock_status",b"lock_status","lock_time",b"lock_time","room_shield",b"room_shield"]) -> None: ...
global___RoomStatusInfo = RoomStatusInfo

class Shake(google.protobuf.message.Message):
    """震动"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FILE_FIELD_NUMBER: builtins.int
    file: typing.Text
    """文件地址"""

    def __init__(self,
        *,
        file: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file",b"file"]) -> None: ...
global___Shake = Shake
